==> qfsm-0.43.tar.gz: qfsm-0.43/src/Draw.h <==
/*
Copyright (C) 2000,2001 Stefan Duffner 

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef DRAW_H
#define DRAW_H

#include <qpainter.h>
#include <qobject.h>

class Machine;
class GState;
class ScrollView;
class GTransition;
class Options;
class GITransition;
class Grid;
class Transition;

/** 
 * @class Draw
 * @brief Drawing class responsible for all graphical representation.
 *
 */

class Draw : public QObject
{
  Q_OBJECT
  public:
    Draw(QObject*, Options* );

    void drawStates(Machine* , QPainter* , int , int , double );
    void drawState(Machine* m, GState* , QPainter* , int , int , double , 
      bool drawxor=TRUE);
    void drawTransitions(Machine* , QPainter* , int, int, double /*, int, int*/);
    void drawTransition(Machine*, GTransition* , QPainter* , int , int , 
      double , /*int, int,*/ bool drawxor=TRUE, bool dotted=TRUE, 
      bool control_lines=FALSE, bool first=FALSE);
    void drawArrow(GTransition*, QPainter*, QPen, int);
    void drawArrow(GITransition*, QPainter*, QPen, int);
    void drawCondition(Machine* m, GTransition* , QPainter* , int, int, 
      double/*, int, int*/);
    void drawInitialTransition(Machine* m, GITransition* , QPainter*, int, int, 
      double, bool drawxor=FALSE, bool first=FALSE, bool transptext=FALSE);
    void drawGrid(Grid*, QPainter*, int, int, double);

    void calcArrow(GTransition*, double&, double&, double&, double&);
    void calcArrow(GITransition*, double&, double&, double&, double&);
    void calcArrow(double, double, double, double, double&, double&, double&, 
    		double&);

    void drawHeadline(Machine* , QPainter*); // , double);

  private:
    /// Pointer to the application options
    Options* options;
};




#endif

==> qfsm-0.44.tar.gz: qfsm-0.44/src/Draw.h <==
/*
Copyright (C) 2000,2001 Stefan Duffner 

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef DRAW_H
#define DRAW_H

#include <qpainter.h>
#include <qobject.h>

class Machine;
class GState;
class ScrollView;
class GTransition;
class Options;
class GITransition;
class Grid;
class Transition;

/** 
 * @class Draw
 * @brief Drawing class responsible for all graphical representation.
 *
 */

class Draw : public QObject
{
  Q_OBJECT
  public:
    Draw(QObject*, Options* );

    void drawStates(Machine* , QPainter* , int , int , double );
    void drawState(Machine* m, GState* , QPainter* , int , int , double , 
      bool drawxor=TRUE);
    void drawTransitions(Machine* , QPainter* , int, int, double /*, int, int*/);
    void drawTransition(Machine*, GTransition* , QPainter* , int , int , 
      double , /*int, int,*/ bool drawxor=TRUE, bool dotted=TRUE, 
      bool control_lines=FALSE, bool first=FALSE);
    void drawArrow(GTransition*, QPainter*, QPen, int);
    void drawArrow(GITransition*, QPainter*, QPen, int);
    void drawCondition(Machine* m, GTransition* , QPainter* , int, int, 
      double/*, int, int*/);
    void drawInitialTransition(Machine* m, GITransition* , QPainter*, int, int, 
      double, bool drawxor=FALSE, bool first=FALSE, bool transptext=FALSE);
    void drawGrid(Grid*, QPainter*, int, int, double);

    void calcArrow(GTransition*, double&, double&, double&, double&, double& xm, double& ym);
    void calcArrow(GITransition*, double&, double&, double&, double&, double& xm, double& ym);
    void calcArrow(double p1x, double p1y, double p2x, double p2y, 
		     double& xl, double& yl, double& xr, double& yr,
		     double& xm, double& ym);

    void drawHeadline(Machine* , QPainter*); // , double);

  private:
    /// Pointer to the application options
    Options* options;
};




#endif
